==> reference4-1.0-sources.jar: one/xingyi/reference4/person/client/view/PersonAddress12View.java <==
package one.xingyi.reference4.person.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference4.person.IPersonAddress12ViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import one.xingyi.reference4.address.IAddressLine12ViewDefn;
@Deprecated
public interface PersonAddress12View  extends IXingYiView<one.xingyi.reference4.person.client.entitydefn.IPersonClientEntity>{
    public static <T> CompletableFuture<T> get(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonAddress12View, T> fn){return service.get(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id,fn);}
    public static <T> CompletableFuture<Optional<T>> getOptional(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonAddress12View, T> fn){return service.getOptional(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id,fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonAddress12View > edit(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonAddress12View,one.xingyi.reference4.person.client.view.PersonAddress12View> fn){return service.edit(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id, fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonAddress12View> create(HttpServiceCompletableFuture service, String id){return service.create(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id);}
    public static CompletableFuture<IdAndValue<one.xingyi.reference4.person.client.view.PersonAddress12View>> create(HttpServiceCompletableFuture service, one.xingyi.reference4.person.client.view.PersonAddress12View view){return service.createWithoutId(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion, view);}
    public static CompletableFuture<Boolean> delete(HttpServiceCompletableFuture service, String id){return service.delete(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id);}
    //ViewFieldDom(typeDom=ViewType(typeName=one.xingyi.reference4.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference4.address.server.domain.IAddress, forView=one.xingyi.reference4.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference4.address.server.companion.AddressCompanion, entityNameForLens=Address), name=address, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('address');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=ListType(fullTypeName=one.xingyi.core.client.IResourceList<one.xingyi.reference4.address.IAddressLine12ViewDefn>, nested=ViewType(typeName=one.xingyi.reference4.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference4.address.server.domain.IAddress, forView=one.xingyi.reference4.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference4.address.server.companion.AddressCompanion, entityNameForLens=Address), companionName=PackageAndClassName(packageName=one.xingyi.reference4.address.server.companion, className=AddressCompanion), entityNameForLens=Address), name=address, readOnly=false, lensName=lens_Person_address, lensPath={identity}, javascript=function lens_Person_address(){return identityLens();};, templated=false, deprecated=true)]
    default public Lens<PersonAddress12View,one.xingyi.reference4.address.client.view.AddressLine12View>addressLens(){return xingYi().objectLens(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion, one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion.companion,"lens_Person_address");}
    default public one.xingyi.reference4.address.client.view.AddressLine12View address(){ return addressLens().get(this);};
    default public PersonAddress12View withaddress(one.xingyi.reference4.address.client.view.AddressLine12View address){ return addressLens().set(this,address);}
}

==> reference4-1.1-sources.jar: one/xingyi/reference4/person/client/view/PersonAddress12View.java <==
package one.xingyi.reference4.person.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference4.person.IPersonAddress12ViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import one.xingyi.reference4.address.IAddressLine12ViewDefn;
@Deprecated
public interface PersonAddress12View  extends IXingYiView<one.xingyi.reference4.person.client.entitydefn.IPersonClientEntity>{
    public static <T> CompletableFuture<T> get(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonAddress12View, T> fn){return service.get(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id,fn);}
    public static <T> CompletableFuture<Optional<T>> getOptional(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonAddress12View, T> fn){return service.getOptional(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id,fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonAddress12View > edit(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonAddress12View,one.xingyi.reference4.person.client.view.PersonAddress12View> fn){return service.edit(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id, fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonAddress12View> create(HttpServiceCompletableFuture service, String id){return service.create(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id);}
    public static CompletableFuture<IdAndValue<one.xingyi.reference4.person.client.view.PersonAddress12View>> create(HttpServiceCompletableFuture service, one.xingyi.reference4.person.client.view.PersonAddress12View view){return service.createWithoutId(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion, view);}
    public static CompletableFuture<Boolean> delete(HttpServiceCompletableFuture service, String id){return service.delete(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion,id);}
    //ViewFieldDom(typeDom=ViewType(typeName=one.xingyi.reference4.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference4.address.server.domain.IAddress, forView=one.xingyi.reference4.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference4.address.server.companion.AddressCompanion, entityNameForLens=Address), name=address, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('address');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=ViewType(typeName=one.xingyi.reference4.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference4.address.server.domain.IAddress, forView=one.xingyi.reference4.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference4.address.server.companion.AddressCompanion, entityNameForLens=Address), name=address, readOnly=false, lensName=lens_Person_address, lensPath={identity}, javascript=function lens_Person_address(){return identityLens();};, templated=false, deprecated=true)]
    default public Lens<PersonAddress12View,one.xingyi.reference4.address.client.view.AddressLine12View>addressLens(){return xingYi().objectLens(one.xingyi.reference4.person.client.viewcompanion.PersonAddress12ViewCompanion.companion, one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion.companion,"lens_Person_address");}
    default public one.xingyi.reference4.address.client.view.AddressLine12View address(){ return addressLens().get(this);};
    default public PersonAddress12View withaddress(one.xingyi.reference4.address.client.view.AddressLine12View address){ return addressLens().set(this,address);}
}
